var NAVTREEINDEX3 =
{
"group__API__Data__Interfaces.html#ga7cc322b2f03830ec7afbb58b7416a283":[25,9,65],
"group__API__Data__Interfaces.html#ga7d44b8a0594932a8cece13e1cc9932bb":[25,9,72],
"group__API__Data__Interfaces.html#ga7e3ef9efbc7a65adad27f9ac27493493":[25,9,139],
"group__API__Data__Interfaces.html#ga7ea069447f11e836d7b709c97d90b570":[25,9,108],
"group__API__Data__Interfaces.html#ga81160c064d381e20cf874ec053e167f9":[25,9,166],
"group__API__Data__Interfaces.html#ga81b34820b1a410d218ad08528c0317f6":[25,9,157],
"group__API__Data__Interfaces.html#ga821cbbf32e68e9af90dcbeb81b9c7034":[25,9,104],
"group__API__Data__Interfaces.html#ga82eea89e2f23a9fdc1f34c03db68a97b":[25,9,86],
"group__API__Data__Interfaces.html#ga833b734aa76cdee89245cb0710793cf9":[25,9,144],
"group__API__Data__Interfaces.html#ga83ba12ab43444d61f4966dc76aa160d6":[25,9,85],
"group__API__Data__Interfaces.html#ga84a3cc04ef603ab17af6d14f23c6ca00":[25,9,109],
"group__API__Data__Interfaces.html#ga8599a8f318fcadbafcc55f9c568678f1":[25,9,156],
"group__API__Data__Interfaces.html#ga86956bce305447697cb9346bee692b24":[25,9,214],
"group__API__Data__Interfaces.html#ga86b64dc68625997cf3c0bb9eae3ee68a":[25,9,75],
"group__API__Data__Interfaces.html#ga87725438ebaccd40d8b1b90e17b46247":[25,9,39],
"group__API__Data__Interfaces.html#ga88d8275866e6f3f430d01e5909cc17f7":[25,9,168],
"group__API__Data__Interfaces.html#ga8a4c1ddb71e09437717e298c3e2c39f9":[25,9,204],
"group__API__Data__Interfaces.html#ga8aa19dcac39f053949c1bb1b4f5fad1d":[25,9,155],
"group__API__Data__Interfaces.html#ga8c04948b40dc3902e9b3de7a84383381":[25,9,206],
"group__API__Data__Interfaces.html#ga8c40de57e43f28beac889b34d0bc69e4":[25,9,55],
"group__API__Data__Interfaces.html#ga8fa1c7e18fa7c621ec68fc5aa32ef181":[25,9,64],
"group__API__Data__Interfaces.html#ga9037815eabc726906d66140b62c03b9b":[25,9,50],
"group__API__Data__Interfaces.html#ga91461bface98435f7e90d515c4aa04cb":[25,9,23],
"group__API__Data__Interfaces.html#ga9263fae0971cb00a9f9108a4a4b1e285":[25,9,49],
"group__API__Data__Interfaces.html#ga9294121fe81a39b6b5e74e8e66bac3e0":[25,9,153],
"group__API__Data__Interfaces.html#ga95f3f5141265f8a78f8b5802be7ea20c":[25,9,22],
"group__API__Data__Interfaces.html#ga9719eab3a5e9fbaad2837b4a985a3a14":[25,9,106],
"group__API__Data__Interfaces.html#ga97859bcb7bc60911362087eefc9249ed":[25,9,209],
"group__API__Data__Interfaces.html#ga97c7b78c97576eb44741bdd7e2183fa7":[25,9,121],
"group__API__Data__Interfaces.html#ga988036ae1f9385832c2988064a4f27af":[25,9,192],
"group__API__Data__Interfaces.html#ga9d14e3576605217f1a160a710fad8178":[25,9,152],
"group__API__Data__Interfaces.html#ga9dc1bbf7a41070a6fcf82e728cae1542":[25,9,77],
"group__API__Data__Interfaces.html#ga9f6457e4a7e558101dd6ad64076a6a99":[25,9,150],
"group__API__Data__Interfaces.html#gaa093608060a222a89fff01130e9c5c64":[25,9,154],
"group__API__Data__Interfaces.html#gaa15cff8f1148e572348095ac5a2ab421":[25,9,32],
"group__API__Data__Interfaces.html#gaa1d6124d3f84336020897d1df1b1cc50":[25,9,163],
"group__API__Data__Interfaces.html#gaa23416a6d049b276fe57b19e069b68b3":[25,9,62],
"group__API__Data__Interfaces.html#gaa29d5f4bd11fce82cd9a01b0e860bf75":[25,9,216],
"group__API__Data__Interfaces.html#gaa2f2140147f15e7b9eec1443690e357c":[25,9,107],
"group__API__Data__Interfaces.html#gaa35025b4b6126c3f22232cea8915cdad":[25,9,68],
"group__API__Data__Interfaces.html#gaa46eb27abc7439c03776d68062f029d4":[25,9,84],
"group__API__Data__Interfaces.html#gaa7a81bad81376cc0f7b8162a4d8dbacd":[25,9,135],
"group__API__Data__Interfaces.html#gaac406e853e677b31a57f2d54263d2602":[25,9,53],
"group__API__Data__Interfaces.html#gaadbd0557a0ca2178a2ebf7673319f53c":[25,9,92],
"group__API__Data__Interfaces.html#gaaeff5c191edc5f3df8ba1a319acd0af9":[25,9,35],
"group__API__Data__Interfaces.html#gab1c57c537a980a2de5e595b2f6204772":[25,9,27],
"group__API__Data__Interfaces.html#gab2bf7713cad5570775bdf4efec79502d":[25,9,136],
"group__API__Data__Interfaces.html#gab316b2febb2b5fb92e83bbaab780f046":[25,9,40],
"group__API__Data__Interfaces.html#gab328b8e0b234147ebe36ceb8e7a55b0a":[25,9,202],
"group__API__Data__Interfaces.html#gab517790a521d1434d9f52de97091f493":[25,9,177],
"group__API__Data__Interfaces.html#gab5666e2f9f46e4aebe367983347384de":[25,9,98],
"group__API__Data__Interfaces.html#gab59c3b606776bdc54f6ccf3f1db4bf38":[25,9,205],
"group__API__Data__Interfaces.html#gab6e12b04b231773f2eff496f57d29ee8":[25,9,114],
"group__API__Data__Interfaces.html#gab7746e58c367202ad0bc8a2decb1bed8":[25,9,178],
"group__API__Data__Interfaces.html#gab7b07d0d2a253e02e1b2d2260cc3fa94":[25,9,76],
"group__API__Data__Interfaces.html#gab7f9484602aeef560cc2e5904e3b2cff":[25,9,194],
"group__API__Data__Interfaces.html#gab9110ecfa66b148e770a375566c1c19d":[25,9,74],
"group__API__Data__Interfaces.html#gab915146b6d59fbd8e6d04480511f7945":[25,9,17],
"group__API__Data__Interfaces.html#gab91cbc596a65e6a4322b657c79934269":[25,9,137],
"group__API__Data__Interfaces.html#gabb03b0b367f445b692e37ab3237d877f":[25,9,195],
"group__API__Data__Interfaces.html#gabcce7df711e56cafddfd82f8f5ee794b":[25,9,113],
"group__API__Data__Interfaces.html#gabe33df9aebbeab34a9f4f319bff5d3e2":[25,9,142],
"group__API__Data__Interfaces.html#gac046f5fb0472cada47cd44650194b1c8":[25,9,14],
"group__API__Data__Interfaces.html#gac14cfc52c450c81dd4789a7aace79d3b":[25,9,122],
"group__API__Data__Interfaces.html#gac23356ed31839f1d1c52efccb7a99dd7":[25,9,15],
"group__API__Data__Interfaces.html#gac2fe5221c0ccc0d082e5bc65830e497b":[25,9,41],
"group__API__Data__Interfaces.html#gac5fd11be8dd93ebfbbf344623f3c2014":[25,9,123],
"group__API__Data__Interfaces.html#gac739182a43ec4dd00618d783b1f2a16c":[25,9,26],
"group__API__Data__Interfaces.html#gac778227f8ff624d7f7ea04f1407fcb92":[25,9,143],
"group__API__Data__Interfaces.html#gac77fef789ec34682ba00b38dcc501170":[25,9,31],
"group__API__Data__Interfaces.html#gac7b7e5f3d4d9a1468df3b9b92743a9fd":[25,9,158],
"group__API__Data__Interfaces.html#gacb816db830d6991909a35a8c0e93a843":[25,9,185],
"group__API__Data__Interfaces.html#gacc62f1150a403bb550d3538b2bffea17":[25,9,119],
"group__API__Data__Interfaces.html#gacc7903845cb442f141de2b1d9450fc63":[25,9,179],
"group__API__Data__Interfaces.html#gacd706856652f629563bce3c0bb528ec6":[25,9,182],
"group__API__Data__Interfaces.html#gacd95c31b537322b1d4000a1248b9c425":[25,9,187],
"group__API__Data__Interfaces.html#gacd9e0b5bd06d1b7d88be4e0143be8a68":[25,9,13],
"group__API__Data__Interfaces.html#gacee0a9e166f87b48da1f56e1ae5d988d":[25,9,189],
"group__API__Data__Interfaces.html#gad3c08c06e55e86993fa5cb77dce95095":[25,9,101],
"group__API__Data__Interfaces.html#gad4850366b77ead9f60c6f7e1d1064b22":[25,9,89],
"group__API__Data__Interfaces.html#gad51f09163a11aad56f942ee152b28d13":[25,9,129],
"group__API__Data__Interfaces.html#gad5ffed03f141096fca4e1e2583c84e22":[25,9,200],
"group__API__Data__Interfaces.html#gad6ca41b04e0265671d4bf899dd433c1e":[25,9,115],
"group__API__Data__Interfaces.html#gad7e204d690945cbe5145bc8950078291":[25,9,117],
"group__API__Data__Interfaces.html#gad9407e7339eb6c8e32e598b7c4c85d70":[25,9,20],
"group__API__Data__Interfaces.html#gad99e209fafc3ad5e0c4da0de02e5bda2":[25,9,70],
"group__API__Data__Interfaces.html#gada534736df809f642437792b1acd7af8":[25,9,172],
"group__API__Data__Interfaces.html#gadccf196d01dd9c43e931827a86f886b2":[25,9,63],
"group__API__Data__Interfaces.html#gadcf7063b1cd8d0feed7054e6e4d9d217":[25,9,210],
"group__API__Data__Interfaces.html#gaddd9b273ddf82a320f66946228f12103":[25,9,173],
"group__API__Data__Interfaces.html#gade238eb388cbb34bf9a93643bfa4df83":[25,9,25],
"group__API__Data__Interfaces.html#gadf8eac3f96b6e63911f23165141411df":[25,9,29],
"group__API__Data__Interfaces.html#gae2a4195d99eedac191857c43cd454226":[25,9,141],
"group__API__Data__Interfaces.html#gae3d95a1379358cbd85c663c8462da98c":[25,9,16],
"group__API__Data__Interfaces.html#gae48e867d81c554b199b127cf9bd4f5b2":[25,9,207],
"group__API__Data__Interfaces.html#gae5d1dbf657ce2c4f55bce1ac2f982d6a":[25,9,118],
"group__API__Data__Interfaces.html#gae95b657d947e611060590d506d8e15dc":[25,9,34],
"group__API__Data__Interfaces.html#gaea999f5e67e778ac28c0a8bc1633ff28":[25,9,87],
"group__API__Data__Interfaces.html#gaeb6356075b3f57e8c7aeccc85f076d87":[25,9,103],
"group__API__Data__Interfaces.html#gaebeefdd9980c18575924ed9860315bcf":[25,9,151],
"group__API__Data__Interfaces.html#gaec6ca64cc2c52e319b9b73cc4f753658":[25,9,217],
"group__API__Data__Interfaces.html#gaeeb3ff0360cafe3fc54e16da2d002c5b":[25,9,82],
"group__API__Data__Interfaces.html#gaeed0ab452c0906a650097368bd1c6ba3":[25,9,80],
"group__API__Data__Interfaces.html#gaef6039a7976d3ee6c6916df28a08da1a":[25,9,19],
"group__API__Data__Interfaces.html#gaefbbb2e643662ee4d7c816d91e8e14df":[25,9,99],
"group__API__Data__Interfaces.html#gaf011a057a557a66271ce06e8109c11c4":[25,9,73],
"group__API__Data__Interfaces.html#gaf0937aae4bedeb03e9ebbec36cc1dad6":[25,9,102],
"group__API__Data__Interfaces.html#gaf0fa0d2dc99ab880ccfe12061770dad2":[25,9,38],
"group__API__Data__Interfaces.html#gaf1843d7f93510e6bf53da173eb9dd75e":[25,9,159],
"group__API__Data__Interfaces.html#gaf3bd64a64625f45859f596db3bb9b40a":[25,9,42],
"group__API__Data__Interfaces.html#gaf5938ea67a4a2c4f140ec527698bf850":[25,9,181],
"group__API__Data__Interfaces.html#gaf5ea640f2c977e3ae95a6be9b3be3bee":[25,9,127],
"group__API__Data__Interfaces.html#gaf972d52af628f82488eeea311eadb4f6":[25,9,191],
"group__API__Data__Interfaces.html#gafb92c2538dc629d823221c5dc16bd767":[25,9,190],
"group__API__Data__Interfaces.html#gafd439524218c70b6b4a784fb12824c28":[25,9,215],
"group__API__Data__Interfaces.html#gafd9d133c4d658b777d9800eba79765b3":[25,9,37],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca1020cba73248160933d8f6c901293437":[25,9,107,5],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca264b360136a55f91ae62c48faa02f376":[25,9,107,1],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca40a80154bc81a5eb4eea06771010bba3":[25,9,107,6],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca4c3642251b2ddf957338ef2729de7f5f":[25,9,107,3],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca5a50ee28bfd93b68341e7644f3e810aa":[25,9,107,4],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca65cfc4ac63a449dd5da3c40ae63bb949":[25,9,107,0],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca7b3ec1ca579bfc82a35d282ed69b0300":[25,9,107,10],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357ca80d5bec40d12c9b05e1331bab739e39f":[25,9,107,9],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa0881ef4be5491fcfb7df81b9778a247":[25,9,107,12],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357caa45ce766ad2fe7020e82e462390c7b38":[25,9,107,8],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cab24c1ea83c1e376895d316a0981bee0c":[25,9,107,7],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cac55e5bac53f8121d107f4bebf2d26155":[25,9,107,11],
"group__API__Data__Interfaces.html#ggaa2f2140147f15e7b9eec1443690e357cacb8ea4adb7ed650338bfe9e69d3e1bb2":[25,9,107,2],
"group__API__Data__Interfaces.html#structstarpu__bcsr__interface":[25,9,10],
"group__API__Data__Interfaces.html#structstarpu__block__interface":[25,9,4],
"group__API__Data__Interfaces.html#structstarpu__coo__interface":[25,9,3],
"group__API__Data__Interfaces.html#structstarpu__csr__interface":[25,9,9],
"group__API__Data__Interfaces.html#structstarpu__data__copy__methods":[25,9,0],
"group__API__Data__Interfaces.html#structstarpu__data__interface__ops":[25,9,1],
"group__API__Data__Interfaces.html#structstarpu__matrix__interface":[25,9,2],
"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops":[25,9,11],
"group__API__Data__Interfaces.html#structstarpu__multiformat__interface":[25,9,12],
"group__API__Data__Interfaces.html#structstarpu__ndim__interface":[25,9,6],
"group__API__Data__Interfaces.html#structstarpu__tensor__interface":[25,9,5],
"group__API__Data__Interfaces.html#structstarpu__variable__interface":[25,9,8],
"group__API__Data__Interfaces.html#structstarpu__vector__interface":[25,9,7],
"group__API__Data__Management.html":[25,8],
"group__API__Data__Management.html#ga00223a2f0608eb7893e87119937931d3":[25,8,58],
"group__API__Data__Management.html#ga06b01fdf769f8f2eb222ecde42afbc81":[25,8,17],
"group__API__Data__Management.html#ga07d895064336867923716b7c690c077d":[25,8,14],
"group__API__Data__Management.html#ga10d43386322955cba25889cf9b88b706":[25,8,48],
"group__API__Data__Management.html#ga1f5ba1c1cfefc1f81a4095cf3c213e54":[25,8,53],
"group__API__Data__Management.html#ga1fb3a1ff8622747d653d1b5f41bc41db":[25,8,5],
"group__API__Data__Management.html#ga23ad7e71f5e785d80c55cdf292c34ea8":[25,8,15],
"group__API__Data__Management.html#ga273df19e4cad1c05ec5df697bcec4444":[25,8,45],
"group__API__Data__Management.html#ga2ae876d62ebaf6e402c85991c912f21e":[25,8,55],
"group__API__Data__Management.html#ga2b9b64ac9a650d8c8942b4227e6fce75":[25,8,2],
"group__API__Data__Management.html#ga337cf01e2a0ccc1c3cc2ea27d5bdf131":[25,8,34],
"group__API__Data__Management.html#ga358aba7459b7f99a6dbaa189ce57b925":[25,8,21],
"group__API__Data__Management.html#ga3b2ca6406b5839062346200123551638":[25,8,20],
"group__API__Data__Management.html#ga4e82fe020ec010bcacb6aee16021607c":[25,8,16],
"group__API__Data__Management.html#ga4fa34753bff1d29c20f0a0e361020b4e":[25,8,13],
"group__API__Data__Management.html#ga5458fc0ffdc4b6bae960520f5f599ae5":[25,8,40],
"group__API__Data__Management.html#ga57687b811ced00dbfc35af73164a72aa":[25,8,37],
"group__API__Data__Management.html#ga586146498466b60d6b81145dfaeb8948":[25,8,11],
"group__API__Data__Management.html#ga5b95764e9545fc367cb995950e82f449":[25,8,29],
"group__API__Data__Management.html#ga5fd09305716ce9d3a5a9fd2df6bc7792":[25,8,60],
"group__API__Data__Management.html#ga690e27502b042cbc6969c5f3c5771a84":[25,8,25],
"group__API__Data__Management.html#ga6e0e15426e75b43f7b44e3f3a38c01f1":[25,8,51],
"group__API__Data__Management.html#ga70ee8a92cbb3935ec3ca0d40f443f860":[25,8,23],
"group__API__Data__Management.html#ga78ffeb2e27e87bfc118e7fe2157ae4c2":[25,8,27],
"group__API__Data__Management.html#ga7badde35fa2205201fad73fd851133fa":[25,8,30],
"group__API__Data__Management.html#ga80778d87c0e2181096124f03bebe53cd":[25,8,6],
"group__API__Data__Management.html#ga80b7284bb413ae7acac0fe83268c10f1":[25,8,50],
"group__API__Data__Management.html#ga8771ea54051655e68ed7a95b4b831fc7":[25,8,32],
"group__API__Data__Management.html#ga88a1a866445372adf0a07a349ecc7a5a":[25,8,10],
"group__API__Data__Management.html#ga8b98dee994de7c323a81ac6e573e5693":[25,8,49],
"group__API__Data__Management.html#ga8bcfd56807cf9436eca71c6e3ade2dab":[25,8,41],
"group__API__Data__Management.html#ga8db878885ebbee4729d8aed6a0479262":[25,8,22],
"group__API__Data__Management.html#ga916df5cfe739f832d51bd66012b500cb":[25,8,31],
"group__API__Data__Management.html#ga982a42a7afc942863de2349bc8f201a9":[25,8,26],
"group__API__Data__Management.html#ga9a6122bae224d714383ae775434cdce3":[25,8,52],
"group__API__Data__Management.html#ga9cbc51da2f2b7025c534d6862866bf81":[25,8,33],
"group__API__Data__Management.html#ga9ce32e79b2f07fb474b6ae10006abb1f":[25,8,36],
"group__API__Data__Management.html#ga9d4db8e3a8a6ea4c6757a455849e1504":[25,8,8],
"group__API__Data__Management.html#gaa1f95d17759711f7703bf02820e2e49b":[25,8,12],
"group__API__Data__Management.html#gaa62248a017ee1494ca399789d7687aac":[25,8,61],
"group__API__Data__Management.html#gaa9084f77b596022f0635b5e326bc450e":[25,8,7],
"group__API__Data__Management.html#gaaaaa769d715f01b5636a837fd86c9671":[25,8,59],
"group__API__Data__Management.html#gab3f057daac283b3b7351b03b0d574493":[25,8,43],
"group__API__Data__Management.html#gab9497db9ea78dafa7ba0a2b99a7fc0f2":[25,8,9],
"group__API__Data__Management.html#gab97817681d85c64d7d84e4b9a88c4811":[25,8,54],
"group__API__Data__Management.html#gabd61bf0201af91a3d4e6501ebdf8e851":[25,8,4],
"group__API__Data__Management.html#gac561fd637be17b74f0456106dc25f5d1":[25,8,35],
"group__API__Data__Management.html#gac83c13a23641632701971e2d48f7c5fa":[25,8,56],
"group__API__Data__Management.html#gac88c5f320d2c900923b7934d9a733104":[25,8,46],
"group__API__Data__Management.html#gaceb23371963b642f4155ffa728f3bf03":[25,8,1],
"group__API__Data__Management.html#gad5a24f94d0aa2bbfab8957c3dd13949a":[25,8,39],
"group__API__Data__Management.html#gad6bed33cdb76ef504efcdf05e5788076":[25,8,3],
"group__API__Data__Management.html#gadc145017bafa2948109c624715de77a2":[25,8,28],
"group__API__Data__Management.html#gae53e7b21c7426c9845a1046cfe5becce":[25,8,44],
"group__API__Data__Management.html#gae5f926615eaa6e318ee0fc4ac0be9e3e":[25,8,38],
"group__API__Data__Management.html#gae6eb535cf9bf46a7ef9ad2d845c675a2":[25,8,19],
"group__API__Data__Management.html#gaedc8031c1b437d35232cd1700d83d472":[25,8,18],
"group__API__Data__Management.html#gaef7203edaf1725977dffac23296ede4e":[25,8,47],
"group__API__Data__Management.html#gaf2811b5c7d3570edf483ca1ece4bf4a0":[25,8,62],
"group__API__Data__Management.html#gaf385e328d71dc2e202b17ec26f229414":[25,8,0],
"group__API__Data__Management.html#gaf971c53b3fa3d3746a8ae1f5291c7c4f":[25,8,57],
"group__API__Data__Management.html#gafd48044a523ed5a4e11598596096dc52":[25,8,24],
"group__API__Data__Management.html#gafd4b4f7f9f0a26f65a1e149525a09bfd":[25,8,42],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba408d8f229f4e9bc746c35725c4000f00":[25,8,5,12],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba4b095bb54466cef653c30284bc31b79e":[25,8,5,9],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba5531afb0a53e301d4bff753fed705179":[25,8,5,4],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba57727da3bb21784bb7949dfa334b4c6e":[25,8,5,13],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba5e9a6cc56e05350429ee4438ce47d504":[25,8,5,7],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba628e5483f4cb6e44779aea39300dafed":[25,8,5,2],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dba9fb7d314ccc154aead02dab90f8db52b":[25,8,5,3],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaa92c1e935fb451cc339a21976680ee05":[25,8,5,5],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaab55b4cef9cfedeacae7012cd52e5389":[25,8,5,1],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbacc08b511187f8c1d9f81652f9c97a013":[25,8,5,11],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbade64878c777f3655d8802cbc6b48a95d":[25,8,5,6],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbae91fbbc42c9e5082cbd704016cf5fa96":[25,8,5,8],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbaecd4ea8fd4083c02cfe0f32742f37705":[25,8,5,10],
"group__API__Data__Management.html#gga1fb3a1ff8622747d653d1b5f41bc41dbafd6a1ff04c61fdecf309f45e01e91a16":[25,8,5,0],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cda2a3b541397e36d47ca5dc53eae3ae3bc":[25,8,6,1],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cda39bf29faf6696902c4b7dc49a172d0f4":[25,8,6,2],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cda7c3a0c090326084ae5598883fe4b5bdb":[25,8,6,3],
"group__API__Data__Management.html#gga80778d87c0e2181096124f03bebe53cdae5376738a045e337ad5519fb2b0c4ba5":[25,8,6,0],
"group__API__Data__Partition.html":[25,10],
"group__API__Data__Partition.html#a0794c07d3fbfab35b6889760699c7b91":[25,10,0,0],
"group__API__Data__Partition.html#a1ef5f824cca130aa51505b0551eca51c":[25,10,0,5],
"group__API__Data__Partition.html#a6cb433cf6efd383c6739099dccb3c2b0":[25,10,0,3],
"group__API__Data__Partition.html#a6cb631e64e61f862647040852fdabe49":[25,10,0,4],
"group__API__Data__Partition.html#aca2a185107bc8d8adc11557248cf454b":[25,10,0,2],
"group__API__Data__Partition.html#aec46586c98b5631201151b7582724e12":[25,10,0,1],
"group__API__Data__Partition.html#ga009a98e4a9780344e2f612732e820755":[25,10,43],
"group__API__Data__Partition.html#ga0e1bee4821237529d554605d333e9109":[25,10,24],
"group__API__Data__Partition.html#ga0f30a9d20dddf5c724f5253195dca268":[25,10,62],
"group__API__Data__Partition.html#ga117176bbe14cf26ae320fc5e1159216d":[25,10,91],
"group__API__Data__Partition.html#ga11ccadcd18ac19c6eb8710f90a561493":[25,10,9],
"group__API__Data__Partition.html#ga11e9d648c2cee65281f4d7b8d6d56a42":[25,10,58],
"group__API__Data__Partition.html#ga1363109ba0e36c1b6c7f1a40c9608791":[25,10,1],
"group__API__Data__Partition.html#ga14703620f86c508cf7ab773e86fd4f90":[25,10,79],
"group__API__Data__Partition.html#ga15a28291a5045ef7ed3c93afc94ed248":[25,10,8],
"group__API__Data__Partition.html#ga1897ebbc75bfec8ae1681bd8676635cd":[25,10,52],
"group__API__Data__Partition.html#ga1a265ffca51fae58701832a4daa53bd9":[25,10,44],
"group__API__Data__Partition.html#ga205e5302dbeca2f8bce15531a6720b09":[25,10,74],
"group__API__Data__Partition.html#ga212189d3b83dfa4e225609b5f2bf8461":[25,10,37],
"group__API__Data__Partition.html#ga2318b60efcf9eb250d548ddc9a33925d":[25,10,84],
"group__API__Data__Partition.html#ga2925be576ac7d597ecead381ff32a894":[25,10,31],
"group__API__Data__Partition.html#ga29e07c2c0604da63e7746a8018d8a62f":[25,10,3],
"group__API__Data__Partition.html#ga2b713d3a7a34dfd7416135d071aa3e48":[25,10,81],
"group__API__Data__Partition.html#ga305da4bdb4c0990aa53dbcc8f5dd4678":[25,10,76],
"group__API__Data__Partition.html#ga3233e3203e0541138cce8152c3ab9aa0":[25,10,56]
};
